Eskapade examples
-----------------

Many Eskapade example macros can be found in the ``python/eskapade/tutorials`` directory.
Together they form a knowledge repository of the tools available in Eskapade.

The numbering of the example macros is as follows:

* esk100+: basic macros describing the chains, links, and datastore functionality of Eskapade.
           They explain the basic architecture of Eskapade, i.e. how the chains, links, 
           datastore, and process manager interact.
* esk200+: macros describing links to do basic processing of pandas dataframes.
* esk300+: visualization macros for making histograms, plots and reports of datasets.
* esk500+: macros for doing data quality assessment and cleaning.
* esk600+: macros describing links to do basic processing of data and rdds with Spark.

We invite you go through them, and encourage you to run the examples to see what 
Eskapade can do for you!

